==> haskell-hspec-core-2.5.1-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-core
version: 2.5.1
id: hspec-core-2.5.1-AIdQcMJAAoXHjzqriebHVq
key: hspec-core-2.5.1-AIdQcMJAAoXHjzqriebHVq
license: MIT
copyright: (c) 2011-2018 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.
category: Testing
abi: 544fafb38bf1bebe06c53f151f2e7759
exposed: True
exposed-modules:
    Test.Hspec.Core.Formatters Test.Hspec.Core.Hooks
    Test.Hspec.Core.QuickCheck Test.Hspec.Core.Runner
    Test.Hspec.Core.Spec Test.Hspec.Core.Util
hidden-modules: Test.Hspec.Core.Clock Test.Hspec.Core.Compat
                Test.Hspec.Core.Config Test.Hspec.Core.Config.Options
                Test.Hspec.Core.Config.Util Test.Hspec.Core.Example
                Test.Hspec.Core.Example.Location Test.Hspec.Core.FailureReport
                Test.Hspec.Core.Format Test.Hspec.Core.Formatters.Diff
                Test.Hspec.Core.Formatters.Free Test.Hspec.Core.Formatters.Internal
                Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.QuickCheckUtil
                Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Spec.Monad
                Test.Hspec.Core.Timer Test.Hspec.Core.Tree Control.Concurrent.Async
                Data.Algorithm.Diff Paths_hspec_core
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-core-2.5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-core-2.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hspec-core-2.5.1
hs-libraries: HShspec-core-2.5.1-AIdQcMJAAoXHjzqriebHVq
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    ansi-terminal-0.8.0.4-HZ5uOkWM5Gb4ksiKJemtLG array-0.5.2.0
    base-4.11.1.0 call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq
    clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2
    hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk
    quickcheck-io-0.2.0-Ecz5aZHo1Ni4V43YDiqW58
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl stm-2.4.5.0
    tf-random-0.5-I39p3qgWMzeLwkvBknVuZq transformers-0.5.5.0
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             ansi-terminal-0.8.0.4-HZ5uOkWM5Gb4ksiKJemtLG=eaed657d24f75590faf3b67ce55e7410
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq=842aa1f6a3dc6ac6e201dfeb465a9bd8
             clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs=6b9ed802e71695075777b6e69687e9b7
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk=0f0d928add941ac9e4a9f5dba9348ac8
             quickcheck-io-0.2.0-Ecz5aZHo1Ni4V43YDiqW58=c680df23e682430249bcd1d9f441fd63
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl=a429d798ab9c438c1f0078c2ad19fe61
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             tf-random-0.5-I39p3qgWMzeLwkvBknVuZq=a5f9e7f35c2dd2438de490ec75468716
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html: /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-core-2.5.1-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-core
version: 2.5.1
id: hspec-core-2.5.1-KXDABWqkFzF6hq4NMaEMaR
key: hspec-core-2.5.1-KXDABWqkFzF6hq4NMaEMaR
license: MIT
copyright: (c) 2011-2018 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.
category: Testing
abi: 8796e4a7b0372ed7b4830254d4aa6c6f
exposed: True
exposed-modules:
    Test.Hspec.Core.Formatters Test.Hspec.Core.Hooks
    Test.Hspec.Core.QuickCheck Test.Hspec.Core.Runner
    Test.Hspec.Core.Spec Test.Hspec.Core.Util
hidden-modules: Test.Hspec.Core.Clock Test.Hspec.Core.Compat
                Test.Hspec.Core.Config Test.Hspec.Core.Config.Options
                Test.Hspec.Core.Config.Util Test.Hspec.Core.Example
                Test.Hspec.Core.Example.Location Test.Hspec.Core.FailureReport
                Test.Hspec.Core.Format Test.Hspec.Core.Formatters.Diff
                Test.Hspec.Core.Formatters.Free Test.Hspec.Core.Formatters.Internal
                Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.QuickCheckUtil
                Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Spec.Monad
                Test.Hspec.Core.Timer Test.Hspec.Core.Tree Control.Concurrent.Async
                Data.Algorithm.Diff Paths_hspec_core
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-core-2.5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-core-2.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hspec-core-2.5.1
hs-libraries: HShspec-core-2.5.1-KXDABWqkFzF6hq4NMaEMaR
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    ansi-terminal-0.8.0.4-HZ5uOkWM5Gb4ksiKJemtLG array-0.5.2.0
    base-4.11.1.0 call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq
    clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2
    hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk
    quickcheck-io-0.2.0-Ecz5aZHo1Ni4V43YDiqW58
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl stm-2.4.5.0
    tf-random-0.5-I39p3qgWMzeLwkvBknVuZq transformers-0.5.5.0
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=0b62adbb61d61aac8d449588192e831b
             ansi-terminal-0.8.0.4-HZ5uOkWM5Gb4ksiKJemtLG=eaed657d24f75590faf3b67ce55e7410
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq=842aa1f6a3dc6ac6e201dfeb465a9bd8
             clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs=6b9ed802e71695075777b6e69687e9b7
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk=0f0d928add941ac9e4a9f5dba9348ac8
             quickcheck-io-0.2.0-Ecz5aZHo1Ni4V43YDiqW58=c680df23e682430249bcd1d9f441fd63
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=8df244958947206247b1dd733653312e
             setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl=a429d798ab9c438c1f0078c2ad19fe61
             stm-2.4.5.0=cd8ccc9f17cf51980f6d59f12e77db7d
             tf-random-0.5-I39p3qgWMzeLwkvBknVuZq=a5f9e7f35c2dd2438de490ec75468716
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
haddock-interfaces: /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html: /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
